# steganographr-python
Port of neatnik/steganographr into a usable language

https://github.com/neatnik/steganographr

Install:

```bash
pip install steganographr
```

Primary functions:
- steganographr.encode
- steganographr.decode

As a command line program
`python3 -m steganographr -h` or `steganographr -h` or `stegnr -h`
